<?php // $Id: editquestion.php,v 1.1.2.1 2006/07/18 15:27:51 tjhunt Exp $

    if (!empty($options->answers)) {
        $answersraw = get_records_list('question_answers', 'id', $options->answers);

    }

    $answers = array();
    if (!empty($answersraw)) {
        foreach ($answersraw as $answer) {
            $answers[] = $answer;   // insert answers into slots
        }
    }

    $yesnooptions = array();
    $yesnooptions[0] = get_string('no');
    $yesnooptions[1] = get_string('yes');

    print_heading(get_string('warningmissingtype', 'quiz'));
    require("$CFG->dirroot/question/type/missingtype/editquestion.html");

?>
